@@ -5,10 +5,13 @@
 Functions which serve for general purposes
 """
 
+import os
 import sys
 import psutil
 from pathlib import Path
 
+import re
+
 import typing
 import inspect
 
@@ -582,3 +585,16 @@ def calc_equidistant_weights(n: int) -> list:
 
 
 # ______________________________________________________________________________________________________________________
+
+
+yaml_env_resolver = re.compile(r'\${.+}')
+
+
+def yaml_env_constructor(loader, node):
+    value = node.value
+    match = yaml_env_resolver.match(value)
+    env_var = match.group()[2:-1]
+    return os.environ.get(env_var) + value[match.end():]
+
+
+# ______________________________________________________________________________________________________________________
